#
# spec file for package getmail
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           getmail
Version:        5.6
Release:        bp153.1.11
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Url:            http://pyropus.ca/software/getmail/
Source:         http://pyropus.ca/software/getmail/old-versions/getmail-%{version}.tar.gz
Source99:       %{name}-rpmlintrc
Patch1:         getmail-fix_paths.patch
Summary:        Simple, Secure and Reliable Email Retriever
License:        GPL-2.0
Group:          Productivity/Networking/Email/Utilities
Provides:       python-getmail = %{version}-%{release}
Provides:       python-getmailcore = %{version}-%{release}
%if 0%{?suse_version} > 1110
BuildArch:      noarch
%endif
BuildRequires:  perl
BuildRequires:  python-devel
%py_requires

%description
getmail is intended as a simple, secure, and reliable replacement for
fetchmail. It retrieves email (either all messages, or only unread messages)
from one or more POP3, SPDS, or IMAP4 servers (with or without SSL) for one or
more email accounts, and reliably delivers into qmail-style Maildirs, mboxrd
files, or through external MDAs (command deliveries) specified on a per-account
basis. getmail also has excellent support for domain (multidrop) mailboxes,
including delivering messages to different users or destinations based on the
envelope recipient address.


%package doc

Summary:        Documentation for %{name}
Group:          Productivity/Networking/Email/Utilities

%description doc
getmail is intended as a simple, secure, and reliable replacement for
fetchmail.

This package contains the configuration, FAQ and troubleshooting
documentation, under %{_docdir}/%{name}/

%prep
%setup -q
%patch1 -p1
%__sed -i \
	-e 's|@@DOCDIR@@|%{_docdir}/%{name}|g' \
	-e 's|@@MANDIR@@|%{_mandir}|g' \
	setup.py

pushd getmailcore
%__perl -ni -e 'print $_ unless m|^#!\s*/|' *.py
%__chmod 0644 *.py
popd #getmailcore

%build
CFLAGS="%{optflags}" \
%__python ./setup.py build

%install
%__python ./setup.py install \
	--prefix="%{_prefix}" \
	--root="%{buildroot}" \
	--record-rpm=files.lst

%__perl -ni -e 'chomp; print $_,"\n" unless m|^(%dir\s+)?%{_docdir}/?$|' files.lst
%__perl -pi -e 's/^/%doc / if m|^(%dir\s+)?%{_docdir}/|' files.lst
%__perl -pi -e 's/$/*/ if m|^%{_mandir}/|' files.lst

%__perl -ni -e 'print unless m,%{_docdir}/%{name}/.+\.(html|txt|css)$,' files.lst

%files -f files.lst
%defattr(-,root,root,0755)
%doc %dir %{_docdir}/%{name}

%files doc
%defattr(-,root,root,0755)
%doc %dir %{_docdir}/%{name}
%{_docdir}/%{name}/*.html
%{_docdir}/%{name}/*.txt
%{_docdir}/%{name}/*.css

%changelog
* Wed Apr  4 2018 cunix@bitmessage.ch
- Update to 5.6
  * add Gmail-specific XOAUTH2 login support for IMAP.
  * fix references to version 4 in README.
* Thu Dec 28 2017 cunix@bitmessage.ch
- Update to 5.5
  * added "record_mailbox" configuration parameter, to allow
    turning off the header getmail adds with this information.
* Fri Oct 13 2017 cunix@bitmessage.ch
- Version bump to 5.4
  * bugfix: fix another error in logging an error condition. Thanks: "ng0".
- Changes from 5.3
  * bugfix: another case where an error condition resulted in getmail
    not displaying the correct message.  Thanks: "ng0".
- Changes from 5.2
  * bugfix: disconnection during IMAP IDLE could result in an error
    message rather than silently exiting.  Thanks: David Gray.
* Tue Jul 18 2017 cunix@bitmessage.ch
- Version bump to 5.1
  * bugfix: if password_command parameter was used with a non-existent
    program, getmail would error out during the handling of that
    condition and not report the problem correctly.
- Changes from 5.0
  * new release numbering scheme; previous version numbers were just
    getting too high.
  * catch and ignore/exit cleanly after reset connection in IMAP IDLE
    mode. Thanks:  Stephan Schulz.
  * allow specifying an expected SSL certificate hostname, for when
    the server's certificate does not match the domain name used to
    connect to it.  Thanks:  "Andre".
  * fix error message not actually giving the header field name
    incorrectly specified as containing the envelope recipient address.
    Thanks:  Hardy Braunsdorf.
  * add new password_command configuration parameter for retrievers,
    allowing getmail to retrieve the account password from any
    arbitrary external command.  Suggestion:  "ng0".
* Sun Apr 30 2017 cunix@bitmessage.ch
- added obs-service verify_file
- Version bump to 4.54.0
  * fix error running getmail_fetch introduced in 4.53.0.
- Changes from 4.53.0
  * fix plaintext version of docs not generated correctly.
  * fix `getmail --fingerprint` not logging server TLS fingerprint correctly
    with SimplePOP3SSLRetriever.
- Changes from 4.52.0
  * add `ignore_header_shrinkage` parameter to Filter_external for users who
    know it is normal for their particular filter to result in a smaller message
    header than the source message, for example when the filter encapsulates
    the original message in a simpler wrapper message.
  * EXPERIMENTAL: when deleting a message from an IMAP mailbox, set the \Seen
    flag in addition to the the \Deleted flag.  This apparently prevents
    the ever-innovatively-broken MSExchange from sending a spurious incorrect
    disposition-notification message to the sender of the message.  I do not
    know if this will cause problems with other broken IMAP server
    implementations; please send a report to the getmail-user's mailing list if
    you see odd behaviour with this change.
  * enable socket timeouts for IMAP SSL classes by default.  They were disabled
    in the code because they were incompatible with SSL in older versions of
    Python.  If you see problems with Python 2.6 or 2.7 now, please let me know.
- Changes from 4.51.0
  * fix exception when using MDA_External and an IMAP mailbox whose name
    contains non-ASCII chars.
- Changes from 4.50.0
  * maybe fix handling of OSX keychain passwords containing double-quote chars.
  * fix getmail erroring out on IMAP folders containing i18n chars.
- Changes from 4.49.0
  * make IMAP class only issue EXPUNGE command on mailbox close if we have
    actually deleted any messages from the open mailbox.  Makes use of read-only
    IMAP folders possible.
- Changes from 4.48.0
  * work around brain-damaged change in Python's poplib which causes
    message retrieval errors if any line of a message has more than
    2048 characters in it.
  * restore link to moved Marc mailing list archive.
- Changes from 4.47.0
  * try to work around pathological breakage in one random POP server
    implementation.
  * remove dead marc.theaimsgroup.com list archive from docs.
  * bugfix: if you combined IMAP IDLE mode with delete_after, getmail would,
    after remaining connected to the server for the number of days configured,
    begin deleting messages immediately after retrieval instead of after the
    configured delay.  Now fixed.
* Wed Oct  8 2014 andreas.stieger@gmx.de
- getmail 4.46.0 [bnc#900217]
  This release fixes several similar vulnerabilities that could
  allow a man-in-the-middle attacker to read encrypted traffic due
  to pack of certificate verification against the hostname.
  * fix --idle checking Python version incorrectly, resulting in
    incorrect warning about running with Python < 2.5
  * add missing support for SSL certificate checking in POP3 which
    broke POP retrieval in v4.45.0
    [CVE-2014-7275]
- includes changes from 4.45.0:
  * perform hostname-vs-certificate matching of SSL certificate if
    validating the certifcate
    [CVE-2014-7274]
  * fix missing plaintext versions of documentation
- includes changes from 4.44.0:
  * add extended SSL options for IMAP retrievers, allowing
    certificate verification and other features
    [CVE-2014-7273]
  * fix missing plaintext versions of documentation
  * fix "Header instance has no attribute 'strip'" error which
    cropped up in some configurations
* Mon Sep 23 2013 lars@linux-schulserver.de
- update to 4.43.0:
  + add IMAP IDLE support
- refreshed getmail-fix_paths.patch
* Fri Aug  9 2013 tchvatal@suse.com
- Remove %%clean phase as it is not required.
* Fri Aug  9 2013 tchvatal@suse.com
- Version bump to 4.42.0:
  * fix problem with non-ascii characters in newly-added message header fields
    with output from Filter_classifier.  Thanks: "Gour"
- Changes from 4.41.0:
  * messages retrieved with POP could have a blank trailing line removed when
    delivered; fixed.  Thanks: Christoph Mitterer, Krzysztof Warzecha.
  * fix an ImportError when IMAP retriever used with getmail under Python 2.4.
- Changes from 4.40.3:
  * increase system recursion limit when run with Python 2.3, to prevent
    recursion errors in parsing some pathologically complex MIME emails.
    Thanks: Kenneth Pronovici.
- Changes from 4.40.2:
  * fix a backwards incompatibility with Python 2.3 and 2.4 introduced in
    getmail 4.38.0.  Thanks: Massimo Zambelli, Krzysztof Warzecha.
- Changes from 4.40.1:
  * again change protocol codes passed to OSX, as they're not only reserved
    codes, but also case-sensitive.  Use the ones an OSX user reports work
    properly.  Thanks: Tim Gray.
- Changes from 4.40.0:
  * convert SIGTERM to SIGINT so getmail can cleanup and exit normally if
    killed with a default signal.  Thanks: Carl Lei.
  * fix change which resulted in passing full protocol name to OSX keyring
    program, which can't handle it (restricted to 4-character code).
    Thanks: Tim Gray.
* Fri Aug  9 2013 tchvatal@suse.com
- Fix the _service usage so we can submit to factory.
* Mon Mar 25 2013 pascal.bleser@opensuse.org
- update to 4.39.1:
  * fix a bug that could crop up when retrieving mail via IMAP from Gmail, and
    the Gmail servers provided weird data in their header extensions.
* Mon Feb 25 2013 dschung@cs.uni-kl.de
- update to 4.39.0:
  * fix an oldmail filename issue that occurred with certain non-ASCII
    characters in an IMAP mailbox name
- changes from 4.38.0:
  * fix retrieving mail from an IMAP mailbox with non-ASCII characters in its
    name causing difficult-to-understand unicode errors during delivery
- changes from 4.37.0:
  * handle IMAP servers which include "/" in message IDs better, so those
    messages aren't always thought to be new
  * record (IMAP) mailbox retrieved from in X-getmail-retrieved-from-mailbox:
    header field, and make it available as %%(mailbox) substitution in
    MDA_external arguments
  * add delete_bigger_than option to allow removal of large messages after
    retrieval, even if not deleting messages otherwise
- changes from 4.36.0:
  * add support for retrieving POP/IMAP passwords from, and storing them to,
    the Gnome keyring
- changes from 4.35.0:
  * fix From_ quoting in mbox delivery; use of the Python stdlib function
    meant getmail was incorrectly using mboxo-style quoting instead of
    mboxrd quoting, probably since early in the v4 series
* Thu Oct 18 2012 pascal.bleser@opensuse.org
- update to 4.34.0:
  * retrieve Gmail metadata (labels, thread ID, message ID) via IMAP extension
    and record it in new message headers
- changes from 4.33.0:
  * allow normal exit on interrupt (ctrl-c) to allow the user to abort message
    retrieval while still remembering already-retrieved messages as successfully
    delivered.  You may get a weird error message after you abort, since the
    server may be in the middle of delivering another message to getmail at the
    time
- changes from 4.32.0:
  * prevent some nuisance stack traces if getmail cannot connect to the POP/
    IMAP server correctly
  * restore use_peek IMAP retriever parameter which accidentally got removed
    in 4.30
- changes from 4.31.0:
  * improved backwards compatibility with pre-v.4.22.0 oldmail files, so IMAP
    mail is not re-retrieved if you upgrade from a 4.22 or earlier to this one;
    no user action necessary
- changes from 4.30.2:
  * fix a nuisance stack trace that would be dumped if a connection failed in
    particular states
- changes from 4.30.1:
  * silence a nuisance deprecation warning about the sets module when running
    with Python >= 2.5 which was reintroduced in 4.29.0
- changes from 4.30.0:
  * fix breakage introduced in 4.29.0 where BrokenUIDLPOP3Retriever would fail
    with a TypeError at logout time
  * fix breakage introduced in 4.29.0 where deleted mail was not being expunged
    from the last (or only) folder retrieved from in an IMAP session
- changes from 4.29.0:
  * ensure getmail exits nonzero if a server refuses login due to a credential
    problem
- changes from 4.28.0:
  * ensure getmail exits nonzero if various error conditions (like POP/IMAP
    authentication failure) occur
  * python versions prior to 2.5.0 contain a bug when dealing with read-only
    IMAP mailboxes.  Monkey-patch imaplib when running with Python<2.5.0.
  * do IMAP modified-utf7 conversion of mailbox names containing non-ASCII
    characters
  * add special ALL value for retrieving mail from all selectable IMAP
    mailboxes in the account
  * change IMAP retrieval strategy to retrieve all messages from a mailbox,
    then move on to the next mailbox, etc.  Should result in increased speed,
    but if you set `max_messages_per_session` too low, this could result in
    later mailboxes not being retrieved from.
* Sun May 20 2012 pascal.bleser@opensuse.org
- update to 4.27.0:
  * make use of IMAP BODY.PEEK configurable; set the IMAP retriever parameter
    `use_peek` to False to disable use of PEEK to get getmail's historical IMAP
    behaviour
* Sun Apr 15 2012 pascal.bleser@opensuse.org
- update to 4.26.0:
  * switch to using BODY.PEEK in IMAP retrieval; upstream no longer see
    problems with this feature in my testing; if users experience
    incompatibility with any IMAP servers where 4.25.0 worked, contact upstream
* Sat Feb 11 2012 pascal.bleser@opensuse.org
- update to 4.25.0:
  * add support for storing POP/IMAP password in OSX keychain
* Mon Dec 12 2011 pascal.bleser@opensuse.org
- update to 4.24.0:
  * add an explicit expunge when closing an IMAP mailbox, for servers that
    incorrectly do not do this when the mailbox is closed
  * fix incorrect section reference for "mailboxes" parameter in documentation
  * fix getmail_fetch broken in 4.21.0
* Sun Nov 20 2011 pascal.bleser@opensuse.org
- update to 4.23.0:
  * fix race if new message shows up in POP3 mailbox between running the UIDL
    and LIST commands
* Fri Nov 18 2011 pascal.bleser@opensuse.org
- update to 4.22.2:
  * ffix an error when logging a bad response to an IMAP SELECT command,
    introduced in 4.21.0
* Sun Oct  2 2011 pascal.bleser@opensuse.org
- update to 4.22.1:
  * fix BrokenUIDLPOP3Retriever breakage from 4.21.0
* Mon Sep 26 2011 pascal.bleser@opensuse.org
- update to 4.22.0:
  * when retriever supports multiple mail folders (IMAP), store oldmail data
    for each folder separately, preventing problems in some cases when using
    multiple rc files with the same account
- changes from 4.21.0:
  * automatically open IMAP folders read-only if neither the delete nor
    delete_after options are in use; necessary to access chatlogs via Gmail
  * avoid sorting msgids on each retrieval, reducing overhead when dealing with
    folders containing thousands of messages
* Thu Jul 21 2011 pascal.bleser@opensuse.org
- update to 4.20.4:
  * more information from the server response is included in the error message
    when an IMAP command errors out
  * Parser is now used instead of HeaderParser to correct illegal formatting
    bogosities in the body parts of incoming messages
* Tue May 31 2011 pascal.bleser@opensuse.org
- update to 4.20.3:
  * fix logging errors in error paths
* Fri May 20 2011 saschpe@suse.de
- Removed authors from description (and shell expansion)
* Sun Apr 10 2011 pascal.bleser@opensuse.org
- update to 4.20.2:
  * better IPv6 handling of the "Received:" header
- changes from 4.20.1:
  * code now ensures that the correct remote address and port are included in
    the "Received:" trace headers generated by getmail; previously, the first
    address found for the server was used even if another address was actually
    used to connect to the server
* Wed Jun 30 2010 pascal.bleser@opensuse.org
- update to 4.20.0:
  * code was fixed from a bad SVN merge that slipped into 4.18.0, triggering
    exceptions in MDA_external configurations
- changes from 4.19.0:
  * fixes missing import introduced in 4.18.0
- dropped getmail-4.18.0-global_name.patch, merged upstream (in 4.19.0)
* Mon Jun 28 2010 lars@linux-schulserver.de
- added getmail-4.18.0-global_name.patch
* Sun Jun 27 2010 pascal.bleser@opensuse.org
- update to 4.18.0:
  * a broken link in the FAQ was updated
  * a few extra characters that were problematic (on non-Unix
    systems) were stripped when generating oldmail filenames -- if
    you are upgrading and your current oldmail file contains any of
    the following characters: "\", ";", "[", "]", or "|", then you
    should rename it, replacing runs of one or more of those
    characters with a single "-"
  * the clarity of the message logged by getmail was improved when
    an external program exits 0 but getmail considers it failed
    because it wrote to stderr
* Fri Apr 30 2010 pascal.bleser@opensuse.org
- update to 4.17.0:
  * changes how getmail counts messages in an IMAP mailbox
  * prevents problems where getmail would only see the first 500
    messages in a mailbox with some IMAP servers that return
    oddball responses to SELECT
* Wed Jan  6 2010 pascal.bleser@opensuse.org
- split most documentation into a -doc subpackage
- update to 4.16.0:
  * an additional fix was made for an IMAP server that offers a
    message it then fails to return -- this allows getmail to
    continue with the next message
- changes from 4.15.0:
  * default port for MultidropIMAPSSLRetriever was incorrect
* Tue Nov 24 2009 pascal.bleser@opensuse.org
- update to 4.14.0:
  * additional cases where IMAP (and for good measure, POP3)
    servers are broken and offer a message that it then fails
    to return were fixed
* Wed Oct 14 2009 pascal.bleser@opensuse.org
- update to 4.13.0:
  * fix new log message not having trailing newline
* Thu Oct  8 2009 pascal.bleser@opensuse.org
- update to 4.12.0:
  * handles MS Exchange failure to deliver messages gracefully
  * documentation updates regarding a Python IMAP memory bug
- changes from 4.11.0:
  * fixed --dump not generating any output for rc files containing
    the "verbose = 0" option
  * fixed a copy-and-paste error in the documentation of
    MultiSorter destination
- changes from 4.10.0:
  * add option "message_log_verbose", defaulting to false:
    if true, the message_log file (and syslog, if used) will
    contain a little more information than the default of just
    messages retrieved
- changes from 4.9.0:
  * adds Kerberos authentication support for IMAP servers
  * eliminates a deprecation warning from Python 2.6
- changes from 4.8.4:
  * adds missing fsync() in the updatefile close method to ensure
    that data actually hits the disk before the rename takes place;
    makes writing of the oldmail file more resilient to system
    crashes
- changes from 4.8.3:
  * improved information is sent to the log file about messages
    not retrieved
- changes from 4.8.2:
  * for IMAP retrievers, message state is kept around for 30 days
    even if the corresponding message isn't seen; this allows
    users to have multiple rc files with different IMAP folders to
    retrieve from without losing their "seen" mail state for the
    folders they're not currently retrieving from
- changes from 4.8.1:
  * fixes the use of the Python 2.4 set builtin in 4.8.0,
    preventing getmail from running on Python 2.3.x
- changes from 4.8.0:
  * better diagnostics when a user invalidly supplies the timeout
    configuration parameter for an IMAP-SSL retriever
- changes from 4.7.8:
  * explicitly closes the current IMAP mailbox when selecting a
    new one, so all servers expunge deleted mail
- changes from 4.7.7:
  * the log message level for stderr output of the destination is
    dropped if ignore_stderr is set, just like for filter
* Tue Nov  6 2007 mrueckert@suse.de
- update to version 4.7.6
  - fix exception when getmail is trying to report a POP3 server
    that completely missed generating a UIDL token for a message.
    Thanks: Hans Lammerts.
- additional changes in 4.7.5
  - make updatefile honour symlinks, so users can alias one
    server's oldmail state file to another (for split-horizon DNS
    and other strange configurations).  Thanks: Scott Hepler.
* Tue Apr 24 2007 mrueckert@suse.de
- update to version 4.7.4
* Mon Feb  5 2007 mrueckert@suse.de
- update to version 4.7.1
  - add max_bytes_per_session option.  Thanks: Robert Spencer.
  - documentation additions.
* Fri Jan 26 2007 mrueckert@suse.de
- update to version 4.7.0
  - make Mboxrd lock type configurable (lockf or flock). Change
    default to lockf. Thanks: Norman Carver.
* Thu Jan  4 2007 mrueckert@suse.de
- update to version 4.6.7:
  better handling for some fatal violations of POP/IMAP protocols.
* Tue Dec 12 2006 mrueckert@suse.de
- update to 4.6.6
* Thu Sep 28 2006 mrueckert@suse.de
- add %%{py_libdir}/site-packages/%%{name}-%%{version}-py%%{py_ver}.egg-info
  to the file list for python 2.5 on Factory
* Thu Sep 28 2006 mrueckert@suse.de
- update to version 4.6.4:
  * Add FAQ about BrokenUIDLPOP3 retrievers.
  * Add better diagnostics for missing/invalid/unwritable state/data
    directory.  Thanks: Christian Authmann.
* Sat Jun 24 2006 mrueckert@suse.de
- Update to version 4.6.3:
  * fix regression: spurious errors thrown when required multidrop
    retriever parameter "envelope_recipient" not present in
    getmailrc file.  Thanks: Elliot Schlegelmilch.
  * fix regression: getmail_fetch no longer properly supported
    external MDAs because of problems parsing the arguments to
    them.  Thanks: ?.
  * change getmail's handling of regular expressions in the
    "locals" parameter of MultiSorter destination to allow it to
    handle backslashes correctly.  Unfortunately this
    means complicating the configuration syntax slightly.
    Thanks: Tim van der Molen.
  * update filters to use new configuration code.
    Remove obsolete code.
